@@ -70,7 +70,7 @@ use strict;
 use Exporter;
 use vars qw{$VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS};
 BEGIN {
-	$VERSION = '0.87';
+	$VERSION = '0.88';
 	@ISA     = qw( Exporter );
 	@EXPORT  = qw(
 		_debug
@@ -268,7 +268,7 @@ sub _debug_desc_fd {
    my $op = pop;
    my $kid = $_[0];
 
-Carp::carp join " ", caller(0), $text, $op  if defined $op  && isa( $op, "IO::Pty" );
+Carp::carp join " ", caller(0), $text, $op  if defined $op  && UNIVERSAL::isa( $op, "IO::Pty" );
 
    _debug(
       $text,
